#!/bin/bash
check() {
    local _program

    for _program in dropbear dropbearkey setterm mktemp pkill ; do
        if ! type -P $_program >/dev/null; then
            derror "Could not find program \"$_program\" required by network."
            return 1
        fi
    done

        return 0
}

depends() {
        echo network
        return 0
}

install() {
        local tmp=$(mktemp -d --tmpdir dracut-sshd.XXXX)

        inst $(which dropbear) /sbin/dropbear
        inst $(which dropbearkey) /sbin/dropbearkey
        dropbear_rsa_key="$tmp"/dropbear_rsa_host_key
        dropbear_dss_key="$tmp"/dropbear_dss_host_key
        dropbearkey -t rsa -f "${dropbear_rsa_key}"
        dropbearkey -t dss -f "${dropbear_dss_key}"
        inst "${dropbear_rsa_key}" /etc/dropbear/dropbear_rsa_host_key
        inst "${dropbear_dss_key}" /etc/dropbear/dropbear_dss_host_key
        grep root /etc/shadow >"$tmp"/shadow
        inst "$tmp"/shadow /etc/shadow
        dropbear_acl=/root/.ssh/authorized_keys
        inst "${dropbear_acl}" /root/.ssh/authorized_keys

        # Generate hooks right here, with parameters baked-in
        [[ -z "${dropbear_port}" ]] && dropbear_port=22
        cat >"$tmp"/sshd_run.sh <<EOF
#!/bin/sh
[ -f /tmp/dropbear.pid ]\
                && kill 0 \$(cat /tmp/dropbear.pid) 2>/dev/null || {
        info 'sshd port: ${dropbear_port}'
        info 'sshd key fingerprint: ${key_fp}'
        info 'sshd key bubblebabble: ${key_bb}'
        /sbin/dropbear -E -m -j -k -p ${dropbear_port} -P /tmp/dropbear.pid
        [ \$? -gt 0 ] && info 'Dropbear sshd failed to start'
}
EOF
        cat >"$tmp"/sshd_kill.sh <<EOF
#!/bin/sh
[ -f /tmp/dropbear.pid ] || exit 0
read main_pid </tmp/dropbear.pid
kill -STOP \${main_pid} 2>/dev/null
pkill -P \${main_pid}
kill \${main_pid} 2>/dev/null
kill -CONT \${main_pid} 2>/dev/null
EOF
        chmod +x "$tmp"/sshd_{run,kill}.sh
        inst_hook cmdline 91 "$tmp"/sshd_run.sh
        inst_hook cleanup 09 "$tmp"/sshd_kill.sh

#       rm -rf "$tmp"
        echo $tmp
        return 0
}

